@@ -118,14 +118,21 @@
 {
     ## cannot call inla.getOption() here as it leads to an infinite recursive call. do this
     ## manually instead.
+    opt.default <- inla.getOption.default()
     if (exists("inla.options", env = inla.get.inlaEnv())) {
-        opt = get("inla.options", env = inla.get.inlaEnv())
-        mkl = if (!is.null(opt$mkl) && opt$mkl) "mkl." else ""
+        opt <- get("inla.options", env = inla.get.inlaEnv())
+        mkl <- if (!is.null(opt$mkl)) opt$mkl else opt.default$mkl
+        lic <- (!is.null(opt$pardiso.license) && nchar(opt$pardiso.license) > 0)
     } else {
-        mkl = ""
+        mkl <- opt.default$mkl
+        lic <- FALSE
     }
+    mkl <- if (mkl) "mkl." else ""
 
     if (inla.os("mac")) {
+        if (nchar(mkl) > 0 && !lic) {
+            mkl <- ""
+        }
         fnm = system.file(paste("bin/mac/", inla.os.32or64bit(), "bit/inla.", mkl, "run", sep=""), package="INLA")
     } else if (inla.os("linux")) {
         fnm = system.file(paste("bin/linux/", inla.os.32or64bit(), "bit/inla.", mkl, "run", sep=""), package="INLA")
@@ -197,9 +204,12 @@
 
     inla.only.for.developers(msg = "inla.my.update", strict = TRUE)
 
-    if (Sys.getenv("USER") %in% c("hrue", "rueh")) {
+    if (Sys.getenv("USER") %in% c("hrue")) {
         dir.default = "~/p/inla/r-inla/rinla/R"
         bin.default = "~/p/inla/work/local/bin"
+    } else if (Sys.getenv("USER") %in% c("rueh")) {
+        dir.default = "~/build64/r-inla/rinla/R"
+        bin.default = "~/build64/local/bin"
     } else if (Sys.getenv("USER") %in% c("elias")) {
         dir.default = "~/inla-project/source/inla/rinla/R"
         bin.default = "~/inla-project/compile/local/bin"
@@ -213,7 +223,7 @@
         dir.default = "~/Desktop/r-inla/rinla/R"
         bin.default = "~/local/bin"
     } else {
-        dir.default = "~/git/inla/rinla/R"
+        dir.default = "~/github/r-inla/rinla/R"
         bin.default = "~/local/bin"
     }
     if (!missing(binaries)) {
@@ -278,8 +288,9 @@
     cat("Source files in ", dir, ". Loaded ", length(files), " files and replaced ", nfuncs, " functions.\n", sep="")
 
     if (binaries) {
-        inla.setOption("inla.call", path.expand(paste(bin.path, "/", "inla", sep="")))
-        inla.setOption("fmesher.call", path.expand(paste(bin.path, "/", "fmesher", sep="")))
+        inla.setOption("inla.call", path.expand(paste(bin.path, "/",
+                                                      if (inla.getOption('mkl')) "inla.mkl.run" else "inla.run", sep="")))
+        inla.setOption("fmesher.call", path.expand(paste(bin.path, "/", "fmesher.run", sep="")))
         cat("Define new values for 'inla.call' and 'fmesher.call'\n", sep="")
     }
 
@@ -355,7 +366,7 @@
     M = inla.as.dgTMatrix(sparseMatrix(i=pmin(size[1], ceiling(AA$i*fac[1])), j=pmin(size[2], ceiling(AA$j*fac[2])), x=1,
             dims = size))
     if (binary.pattern)
-        M[ M != 0 ] = 1
+        M@x[] <- 1
 
     return (M)
 }
@@ -900,7 +911,7 @@
 }
 `inla.ginv` = function(x, tol = sqrt(.Machine$double.eps), rankdef = NULL)
 {
-    ## from MASS:::ginv, but with added option 'rankdef'.
+    ## from MASS::ginv, but with added option 'rankdef'.
     if (!is.matrix(x)) {
         x <- as.matrix(x)
     }
@@ -998,9 +1009,13 @@
         if (is.null(mc.cores)) {
             mc.cores = getOption("mc.cores", NULL)
             if (is.null(mc.cores)) {
-                mc.cores = inla.getOption("num.threads")
-                if (is.null(mc.cores)) {
-                    mc.cores = 2L
+                num.threads = inla.getOption("num.threads")
+                num.threads <- inla.parse.num.threads(num.threads)
+                nt <- as.numeric(strsplit(num.threads, ":")[[1]])
+                if (nt[1] == 0) {
+                    mc.cores = parallel::detectCores(all.tests = TRUE, logical = FALSE)
+                } else {
+                    mc.cores <- nt[1]
                 }
             }
         }
@@ -1088,9 +1103,9 @@
                    " < ", format(lim, scientific=TRUE, digits=4), "\n",
                    "  You can fix this by some kind of binning, see ?inla.group", "\n",
                    "  If you want/need to bypass this check at your own risk, do", "\n",
-                   "\t> m = get(\"inla.models\", INLA:::inla.get.inlaEnv())\n",
+                   "\t> m = get(\"inla.models\", inla.get.inlaEnv())\n",
                    "\t> m$", section, "$", model, "$min.diff = NULL\n",
-                   "\t> assign(\"inla.models\", m, INLA:::inla.get.inlaEnv())"))
+                   "\t> assign(\"inla.models\", m, inla.get.inlaEnv())"))
 
     }
     return (invisible())
